import os, errno
from PIL import Image


def generate_imgs(inpath, outpath, prefixes, w, h):
    try:
        os.makedirs(os.getcwd() + "/../" + outpath)
    except OSError as e:
        if e.errno != errno.EEXIST:
            raise

    img_filename = "XX.pbm";

    for pre in prefixes:
        img = Image.open(os.getcwd() + "/../" + inpath + "/" + pre + img_filename)
        
        # add alpha channel
        img = img.convert("RGBA")

        # for every char (w x h pixels)
        for col in range(0, 16):
            for row in range(0, 16):
                bounds = (col*w, row*h, (col+1)*w, (row+1)*h)
                sec = img.crop(bounds)

                # turn all white pixels transparent
                isallalpha = True
                pixdata = sec.load()
                for y in range(h):
                    for x in range(w):
                        if pixdata[x, y] == (255, 255, 255, 255):
                            pixdata[x, y] = (255, 255, 255, 0)
                        else:
                            isallalpha = False
                
                # skip all alpha chars (non-printable)
                if isallalpha:
                    continue

                filename = pre + "%X%X.png" % (row, col)

                if sec.getbbox() is not None:
                    print(os.getcwd() + "/../" + outpath + filename)
                    sec.save(os.getcwd() + "/../" + outpath + filename)


# mini
inpath = "fontcharacter/reference/mini/"
outpath = "casio_charset/mini/"
prefixes = ("0x", "0x7F", "0xE5", "0xE6")
generate_imgs(inpath, outpath, prefixes, 5, 5)

# normal
inpath = "fontcharacter/reference/normal/"
outpath = "casio_charset/normal/"
prefixes = ("0x", "0x7F", "0xE5", "0xE6", "0xE7")
generate_imgs(inpath, outpath, prefixes, 5, 7)
